"""
backstage shortcuts.py
Shortcut imports for convenience.
"""
from backstage.act.act import Act
from backstage.venue.venue import Venue




from backstage.venue.venue_utils import  new_venue, venue_from_cwd
from backstage.act.act_utils import  new_act






