{%  load settings_tags %}
{%  load staticfiles %}
<h1>Django Backstage</h1>
<h2>{{  csettings.ACT_NAME }} Home Page</h2>
<p>This is the placeholder Act index page template</p>
<p>it is located at</p>
<p><emph>{{ csettings.VENUE_ROOT }}/acts/{{ csettings.ACT_NAME }}/templates/index.html</emph></p>
